<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Informazioni su SMTube</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../about.ui" line="53"/>
        <location filename="../about.ui" line="109"/>
        <location filename="../about.ui" line="165"/>
        <source>icon</source>
        <translation>icona</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Traduttori</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>Browser YouTube%1 per SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Based on UMPlayer</source>
        <translation>Basato su UMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Versione: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Edizione portabile</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Compilato con Qt %1 (usando Qt %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our web for updates:</source>
        <translation>Per ulteriori informazioni visita il nostro sito web:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="98"/>
        <source>Spanish</source>
        <translation>Spagnolo</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="115"/>
        <source>Russian</source>
        <translation>Russo (URSS)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="108"/>
        <source>Lithuanian</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="102"/>
        <source>Japanese</source>
        <translation>Giapponese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>Basque</source>
        <translation>Basco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="104"/>
        <source>Portuguese</source>
        <translation>Portoghese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="119"/>
        <source>Hungarian</source>
        <translation>Ungherese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="114"/>
        <source>Polish</source>
        <translation>Polacco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="111"/>
        <source>Hebrew</source>
        <translation>Ebraico</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="106"/>
        <source>Ukrainian</source>
        <translation>Ucraino</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="125"/>
        <source>Norwegian Nynorsk</source>
        <translation>Norvegese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="101"/>
        <source>Czech</source>
        <translation>Ceco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="92"/>
        <source>Many people contributed with translations.</source>
        <translation>Molte persone hanno già contribuito alla traduzione</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="93"/>
        <source>You can also help to translate SMPlayer into your own language.</source>
        <translation>di SMTube, vuoi contribuire al loro miglioramento o desideri aiutarci con la traduzione di SMPlayer?</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Visita il sito web: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="96"/>
        <source>Current translators from the transifex teams:</source>
        <translation>Persone attualmente coinvolte nel team Transifex:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="103"/>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="109"/>
        <source>Malay</source>
        <translation>Malese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="110"/>
        <source>Portuguese - Brazil</source>
        <translation>Portoghese (Brasile)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="112"/>
        <source>Simplified Chinese</source>
        <translation>Cinese semplificato</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="116"/>
        <source>French</source>
        <translation>Francese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="118"/>
        <source>Danish</source>
        <translation>Danese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="122"/>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="123"/>
        <source>Traditional Chinese</source>
        <translation>Cinese tradizionale</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="126"/>
        <source>Swedish</source>
        <translation>Svedese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="120"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="121"/>
        <source>Finnish</source>
        <translation>Finlandese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="127"/>
        <source>Arabic</source>
        <translation>Arabo</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="128"/>
        <source>Georgian</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="105"/>
        <source>Serbian</source>
        <translation>Serbo</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="100"/>
        <source>Croatian</source>
        <translation>Croato</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="124"/>
        <source>Bulgarian</source>
        <translation>Bulgaro</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="113"/>
        <source>Vietnamese</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>Indonesian</source>
        <translation>Indonesiano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="129"/>
        <source>Arabic - Saudi Arabia</source>
        <translation>Arabo (Arabia Saudita)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="130"/>
        <source>Sinhala</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="131"/>
        <source>Greek</source>
        <translation>Greco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="132"/>
        <source>Estonian</source>
        <translation>Estone</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="133"/>
        <source>N&apos;ko</source>
        <translation>N&apos;ko</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="134"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="135"/>
        <source>Uzbek</source>
        <translation>Uzbeko</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="136"/>
        <source>Catalan</source>
        <translation>Catalano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="137"/>
        <source>Slovak</source>
        <translation>Slovacco</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="138"/>
        <source>British English</source>
        <translation>Inglese Britannico</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="139"/>
        <source>Albanian</source>
        <translation>Albanese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="140"/>
        <source>Dutch</source>
        <translation>Olandese</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="141"/>
        <source>Romanian</source>
        <translation>Rumeno</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="142"/>
        <source>Khmer</source>
        <translation>Cambogiano</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="143"/>
        <source>Telugu</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="144"/>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="145"/>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="170"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="107"/>
        <source>Galician</source>
        <translation>Galiziano</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="37"/>
        <source>Downloading...</source>
        <translation>Scaricamento in corso...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="58"/>
        <source>Connecting to %1</source>
        <translation>Connessione a %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="126"/>
        <source>The Youtube code has been updated successfully.</source>
        <translation>Il codice di YouTube è stato aggiornato con successo.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="127"/>
        <source>Installed version: %1</source>
        <translation>Versione installata: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="128"/>
        <source>Success</source>
        <translation>Operazione completata con successo.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <source>An error happened writing %1</source>
        <translation>Si è verificato un errore di scrittura su %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Si è verificato un errore durante il tentativo di scaricamento del file:&lt;br&gt;%1</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="20"/>
        <source>Recording</source>
        <translation>Download (Registrazioni)</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="28"/>
        <source>&amp;Save to this folder</source>
        <translation>&amp;Salva nella cartella</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="45"/>
        <source>&amp;Quality</source>
        <translation>&amp;Qualità:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="157"/>
        <source>Standard Feeds</source>
        <translation>Feeds Standard</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="163"/>
        <source>&amp;Region:</source>
        <translation>&amp;Nazione:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="189"/>
        <source>Period of &amp;time:</source>
        <translation>Periodo di &amp;tempo:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="80"/>
        <source>Playback</source>
        <translation>Riproduzione</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="88"/>
        <source>Q&amp;uality:</source>
        <translation>Q&amp;ualità:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="125"/>
        <source>&amp;Player:</source>
        <translation>&amp;Lettore:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="40"/>
        <source>All time</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="41"/>
        <source>This month</source>
        <translation>Questo mese</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="42"/>
        <source>This week</source>
        <translation>Questa settimana</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="43"/>
        <source>Today</source>
        <translation>Oggi</translation>
    </message>
</context>
<context>
    <name>DownloadFile</name>
    <message>
        <location filename="../downloadfile.cpp" line="117"/>
        <source>%1 hours</source>
        <translation>%1 ore</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="123"/>
        <source>%1 minutes</source>
        <translation>%1 minuti</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="110"/>
        <source>unknown time remaining</source>
        <translation>tempo restante sconosciuto</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="126"/>
        <source>%1 seconds</source>
        <translation>%1 secondi</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="127"/>
        <source>%1 remaining</source>
        <translation>%1 al termine</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="132"/>
        <source>%1 of %2 MB</source>
        <translation>%1 di %2 MB</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="138"/>
        <source>%1 of %2 KB</source>
        <translation>%1 di %2 KB</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="144"/>
        <source>%1 of %2 bytes</source>
        <translation>%1 di %2 byte</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="148"/>
        <source>%1 of unknown size</source>
        <translation>%1 di dimensione sconosciuta</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="153"/>
        <source>%1 MB/sec</source>
        <translation>%1 MB/s</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="157"/>
        <source>%1 KB/sec</source>
        <translation>%1 KB/s</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="161"/>
        <source>%1 bytes/sec</source>
        <translation>%1 byte/s</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="54"/>
        <source>Click to select a file or folder</source>
        <translation>Clicca per selezionare un file o una cartella</translation>
    </message>
</context>
<context>
    <name>RecordingDelegate</name>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Canceled</source>
        <translation>Interrotto</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="155"/>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="159"/>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="163"/>
        <source>%1 bytes</source>
        <translation>%1 byte</translation>
    </message>
</context>
<context>
    <name>RecordingDialog</name>
    <message>
        <location filename="../recordingdialog.cpp" line="208"/>
        <location filename="../recordingdialog.cpp" line="527"/>
        <source>Recordings</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="209"/>
        <source>&amp;Clear list</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="210"/>
        <location filename="../recordingdialog.cpp" line="658"/>
        <source>&amp;Open folder</source>
        <translation>&amp;Apri cartella</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>There was an error in retrieving the download URL.</source>
        <translation>Si è verificato un errore durante il tentativo di recupero dell&apos;indirizzo da cui scaricare.</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>Recording failed</source>
        <translation>Download fallito</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="413"/>
        <location filename="../recordingdialog.cpp" line="795"/>
        <source>Starting</source>
        <translation>Avviato</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="448"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="452"/>
        <source>Completed</source>
        <translation>Completato</translation>
    </message>
    <message numerus="yes">
        <location filename="../recordingdialog.cpp" line="531"/>
        <source>%1% of %n video - Recordings</source>
        <translation>
            <numerusform>%1% di %n video - Download</numerusform>
            <numerusform>%1% di %n video - Download</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="616"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="618"/>
        <source>&amp;Remove from list</source>
        <translation>&amp;Rimuovi dalla lista</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="639"/>
        <location filename="../recordingdialog.cpp" line="661"/>
        <source>Remove from &amp;list</source>
        <translation>Rimuovi dalla &amp;lista</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="635"/>
        <source>&amp;Retry</source>
        <translation>&amp;Riprova</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="657"/>
        <source>&amp;Play</source>
        <translation>Ri&amp;produci</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="660"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="742"/>
        <source>Fetching URL...</source>
        <translation>Recupero URL...</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="759"/>
        <source>File error</source>
        <translation>Errore nel file</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="760"/>
        <source>The file does not exists, would you like to remove it from the list?</source>
        <translation>Il file non esiste più, si desidera rimuoverlo dalla lista?</translation>
    </message>
</context>
<context>
    <name>Regions</name>
    <message>
        <location filename="../regions.cpp" line="26"/>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="27"/>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="29"/>
        <source>Belgium</source>
        <translation>Belgio</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="30"/>
        <source>Brazil</source>
        <translation>Brasile</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="31"/>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="32"/>
        <source>Chile</source>
        <translation>Cile</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="33"/>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="34"/>
        <source>Czech Republic</source>
        <translation>Repubblica Ceca</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="35"/>
        <source>Egypt</source>
        <translation>Egitto</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="36"/>
        <source>France</source>
        <translation>Francia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="37"/>
        <source>Germany</source>
        <translation>Germania</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="38"/>
        <source>Great Britain</source>
        <translation>Gran Bretagna</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="39"/>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="40"/>
        <source>Hungary</source>
        <translation>Ungheria</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="41"/>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="42"/>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="43"/>
        <source>Israel</source>
        <translation>Israele</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="44"/>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="45"/>
        <source>Japan</source>
        <translation>Giappone</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="46"/>
        <source>Jordan</source>
        <translation>Giordania</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="47"/>
        <source>Malaysia</source>
        <translation>Malesia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="48"/>
        <source>Mexico</source>
        <translation>Messico</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="49"/>
        <source>Morocco</source>
        <translation>Marocco</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="50"/>
        <source>Netherlands</source>
        <translation>Olanda</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="51"/>
        <source>New Zealand</source>
        <translation>Nuova Zelanda</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="52"/>
        <source>Peru</source>
        <translation>Perù</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="53"/>
        <source>Philippines</source>
        <translation>Filippine</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="54"/>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="55"/>
        <source>Russia</source>
        <translation>Russia (URSS)</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="56"/>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudita</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="57"/>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="58"/>
        <source>South Africa</source>
        <translation>Sudafrica</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="59"/>
        <source>South Korea</source>
        <translation>Corea del Sud/Nord</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="60"/>
        <source>Spain</source>
        <translation>Spagna</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="61"/>
        <source>Sweden</source>
        <translation>Svezia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="63"/>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="64"/>
        <source>United Arab Emirates</source>
        <translation>Emirati Arabi Uniti</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="65"/>
        <source>United States</source>
        <translation>Stati Uniti</translation>
    </message>
</context>
<context>
    <name>YTDelegate</name>
    <message>
        <location filename="../ytdelegate.cpp" line="115"/>
        <source>%L1 views</source>
        <translation>%L1 visualizzazioni</translation>
    </message>
</context>
<context>
    <name>YTDialog</name>
    <message>
        <location filename="../ytdialog.cpp" line="227"/>
        <source>YouTube Browser - SMPlayer</source>
        <translation>YouTube Browser - SMPlayer</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="277"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="283"/>
        <source>Information</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="290"/>
        <source>Show recordings</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="296"/>
        <source>Enter URL</source>
        <translation>Inserisci URL</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="497"/>
        <source>Most Relevant</source>
        <translation>Più Rilevanti</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="501"/>
        <source>Most Recent</source>
        <translation>Più Recenti</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="505"/>
        <source>Most Viewed</source>
        <translation>Più Visti</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="509"/>
        <source>Most Popular</source>
        <translation>Più Popolari</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="535"/>
        <source>Most popular videos on YouTube%1</source>
        <translation>Video più popolari di YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="656"/>
        <source>Error: Could not connect to Youtube server.</source>
        <translation>Errore: Impossibile connettersi al server di YouTube.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="766"/>
        <source>R&amp;ecord audio</source>
        <translation>Scarica &amp;audio</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="771"/>
        <source>&amp;Add URL to the SMPlayer playlist</source>
        <translation>&amp;Aggiungi URL alla playlist di SMPlayer</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="839"/>
        <source>Enter a URL</source>
        <translation>Inserisci un URL</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="963"/>
        <location filename="../ytdialog.cpp" line="974"/>
        <source>Problems with Youtube</source>
        <translation>Problemi con YouTube</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="965"/>
        <source>Do you want to update the Youtube code? This may fix the problem.</source>
        <translation>Si desidera aggiornare il codice di YouTube? Questa operazione potrebbe risolvere il problema.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="964"/>
        <location filename="../ytdialog.cpp" line="975"/>
        <source>Unfortunately due to changes in Youtube, the video &apos;%1&apos; can&apos;t be played or recorded.</source>
        <translation>Sfortunatamente a causa delle recenti modifiche apportate a YouTube il video &apos;%1&apos; che si sta cercando non è più visualizzabile o registrabile.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="976"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Il problema potrebbe essere aggirabile aggiornando questa applicazione.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="540"/>
        <source>YouTube%2 results for &quot;%1&quot;</source>
        <translation>YouTube%2 risultati per &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="513"/>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="517"/>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="536"/>
        <source>Most popular sport videos on YouTube%1</source>
        <translation>Video sportivi più popolari di YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="537"/>
        <source>Most popular music videos on YouTube%1</source>
        <translation>Video musicali più popolari di YouTube%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="664"/>
        <source>No videos found</source>
        <translation>Nessun video trovato</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="666"/>
        <source>No videos found for &quot;%1&quot;</source>
        <translation>Nessun video trovato per &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="763"/>
        <source>&amp;Play video</source>
        <translation>&amp;Riproduci video</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="765"/>
        <source>&amp;Record video</source>
        <translation>Scarica &amp;video</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="768"/>
        <source>&amp;Watch on YouTube</source>
        <translation>&amp;Mostra su YouTube</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="769"/>
        <source>&amp;Copy link</source>
        <translation>Copia &amp;indirizzo</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="252"/>
        <source>Next</source>
        <translation>Successiva</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="258"/>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="840"/>
        <source>Enter a Youtube URL to record</source>
        <translation>Inserisci indirizzo per scaricare da YouTube</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="949"/>
        <location filename="../ytdialog.cpp" line="951"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
</context>
</TS>
